# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicemanagement/v1/servicemanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import service_pb2 as google_dot_api_dot_service__pb2
from google.api.servicemanagement.v1 import resources_pb2 as google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4google/api/servicemanagement/v1/servicemanager.proto\x12\x1fgoogle.api.servicemanagement.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x18google/api/service.proto\x1a/google/api/servicemanagement/v1/resources.proto\x1a#google/longrunning/operations.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/rpc/status.proto\"r\n\x13ListServicesRequest\x12\x1b\n\x13producer_project_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t\x12\x17\n\x0b\x63onsumer_id\x18\x07 \x01(\tB\x02\x18\x01\"r\n\x14ListServicesResponse\x12\x41\n\x08services\x18\x01 \x03(\x0b\x32/.google.api.servicemanagement.v1.ManagedService\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"/\n\x11GetServiceRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"^\n\x14\x43reateServiceRequest\x12\x46\n\x07service\x18\x01 \x01(\x0b\x32/.google.api.servicemanagement.v1.ManagedServiceB\x04\xe2\x41\x01\x02\"2\n\x14\x44\x65leteServiceRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"4\n\x16UndeleteServiceRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"[\n\x17UndeleteServiceResponse\x12@\n\x07service\x18\x01 \x01(\x0b\x32/.google.api.servicemanagement.v1.ManagedService\"\xc4\x01\n\x17GetServiceConfigRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tconfig_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12Q\n\x04view\x18\x03 \x01(\x0e\x32\x43.google.api.servicemanagement.v1.GetServiceConfigRequest.ConfigView\"!\n\nConfigView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\"^\n\x19ListServiceConfigsRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\"c\n\x1aListServiceConfigsResponse\x12,\n\x0fservice_configs\x18\x01 \x03(\x0b\x32\x13.google.api.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"k\n\x1a\x43reateServiceConfigRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x31\n\x0eservice_config\x18\x02 \x01(\x0b\x32\x13.google.api.ServiceB\x04\xe2\x41\x01\x02\"\xa0\x01\n\x19SubmitConfigSourceRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12J\n\rconfig_source\x18\x02 \x01(\x0b\x32-.google.api.servicemanagement.v1.ConfigSourceB\x04\xe2\x41\x01\x02\x12\x1b\n\rvalidate_only\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\"I\n\x1aSubmitConfigSourceResponse\x12+\n\x0eservice_config\x18\x01 \x01(\x0b\x32\x13.google.api.Service\"z\n\x1b\x43reateServiceRolloutRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12?\n\x07rollout\x18\x02 \x01(\x0b\x32(.google.api.servicemanagement.v1.RolloutB\x04\xe2\x41\x01\x02\"u\n\x1aListServiceRolloutsRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\"r\n\x1bListServiceRolloutsResponse\x12:\n\x08rollouts\x18\x01 \x03(\x0b\x32(.google.api.servicemanagement.v1.Rollout\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x18GetServiceRolloutRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x18\n\nrollout_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\"M\n\x14\x45nableServiceRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0b\x63onsumer_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\"\x17\n\x15\x45nableServiceResponse\"N\n\x15\x44isableServiceRequest\x12\x1a\n\x0cservice_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0b\x63onsumer_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\"\x18\n\x16\x44isableServiceResponse\"}\n\x1bGenerateConfigReportRequest\x12.\n\nnew_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x04\xe2\x41\x01\x02\x12.\n\nold_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x04\xe2\x41\x01\x01\"\xc9\x01\n\x1cGenerateConfigReportResponse\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x45\n\x0e\x63hange_reports\x18\x03 \x03(\x0b\x32-.google.api.servicemanagement.v1.ChangeReport\x12@\n\x0b\x64iagnostics\x18\x04 \x03(\x0b\x32+.google.api.servicemanagement.v1.Diagnostic2\x92\x1e\n\x0eServiceManager\x12\xb3\x01\n\x0cListServices\x12\x34.google.api.servicemanagement.v1.ListServicesRequest\x1a\x35.google.api.servicemanagement.v1.ListServicesResponse\"6\xda\x41\x1fproducer_project_id,consumer_id\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/services\x12\xa5\x01\n\nGetService\x12\x32.google.api.servicemanagement.v1.GetServiceRequest\x1a/.google.api.servicemanagement.v1.ManagedService\"2\xda\x41\x0cservice_name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/services/{service_name}\x12\xf5\x01\n\rCreateService\x12\x35.google.api.servicemanagement.v1.CreateServiceRequest\x1a\x1d.google.longrunning.Operation\"\x8d\x01\xca\x41\x63\n.google.api.servicemanagement.v1.ManagedService\x12\x31google.api.servicemanagement.v1.OperationMetadata\xda\x41\x07service\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/services:\x07service\x12\xe6\x01\n\rDeleteService\x12\x35.google.api.servicemanagement.v1.DeleteServiceRequest\x1a\x1d.google.longrunning.Operation\"\x7f\xca\x41J\n\x15google.protobuf.Empty\x12\x31google.api.servicemanagement.v1.OperationMetadata\xda\x41\x0cservice_name\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/services/{service_name}\x12\x96\x02\n\x0fUndeleteService\x12\x37.google.api.servicemanagement.v1.UndeleteServiceRequest\x1a\x1d.google.longrunning.Operation\"\xaa\x01\xca\x41l\n7google.api.servicemanagement.v1.UndeleteServiceResponse\x12\x31google.api.servicemanagement.v1.OperationMetadata\xda\x41\x0cservice_name\x82\xd3\xe4\x93\x02&\"$/v1/services/{service_name}:undelete\x12\xc9\x01\n\x12ListServiceConfigs\x12:.google.api.servicemanagement.v1.ListServiceConfigsRequest\x1a;.google.api.servicemanagement.v1.ListServiceConfigsResponse\":\xda\x41\x0cservice_name\x82\xd3\xe4\x93\x02%\x12#/v1/services/{service_name}/configs\x12\xde\x01\n\x10GetServiceConfig\x12\x38.google.api.servicemanagement.v1.GetServiceConfigRequest\x1a\x13.google.api.Service\"{\xda\x41\x1bservice_name,config_id,view\x82\xd3\xe4\x93\x02W\x12//v1/services/{service_name}/configs/{config_id}Z$\x12\"/v1/services/{service_name}/config\x12\xc2\x01\n\x13\x43reateServiceConfig\x12;.google.api.servicemanagement.v1.CreateServiceConfigRequest\x1a\x13.google.api.Service\"Y\xda\x41\x1bservice_name,service_config\x82\xd3\xe4\x93\x02\x35\"#/v1/services/{service_name}/configs:\x0eservice_config\x12\xc4\x02\n\x12SubmitConfigSource\x12:.google.api.servicemanagement.v1.SubmitConfigSourceRequest\x1a\x1d.google.longrunning.Operation\"\xd2\x01\xca\x41o\n:google.api.servicemanagement.v1.SubmitConfigSourceResponse\x12\x31google.api.servicemanagement.v1.OperationMetadata\xda\x41(service_name,config_source,validate_only\x82\xd3\xe4\x93\x02/\"*/v1/services/{service_name}/configs:submit:\x01*\x12\xd4\x01\n\x13ListServiceRollouts\x12;.google.api.servicemanagement.v1.ListServiceRolloutsRequest\x1a<.google.api.servicemanagement.v1.ListServiceRolloutsResponse\"B\xda\x41\x13service_name,filter\x82\xd3\xe4\x93\x02&\x12$/v1/services/{service_name}/rollouts\x12\xcd\x01\n\x11GetServiceRollout\x12\x39.google.api.servicemanagement.v1.GetServiceRolloutRequest\x1a(.google.api.servicemanagement.v1.Rollout\"S\xda\x41\x17service_name,rollout_id\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/services/{service_name}/rollouts/{rollout_id}\x12\xa1\x02\n\x14\x43reateServiceRollout\x12<.google.api.servicemanagement.v1.CreateServiceRolloutRequest\x1a\x1d.google.longrunning.Operation\"\xab\x01\xca\x41\\\n\'google.api.servicemanagement.v1.Rollout\x12\x31google.api.servicemanagement.v1.OperationMetadata\xda\x41\x14service_name,rollout\x82\xd3\xe4\x93\x02/\"$/v1/services/{service_name}/rollouts:\x07rollout\x12\xd9\x01\n\x14GenerateConfigReport\x12<.google.api.servicemanagement.v1.GenerateConfigReportRequest\x1a=.google.api.servicemanagement.v1.GenerateConfigReportResponse\"D\xda\x41\x15new_config,old_config\x82\xd3\xe4\x93\x02&\"!/v1/services:generateConfigReport:\x01*\x12\xa0\x02\n\rEnableService\x12\x35.google.api.servicemanagement.v1.EnableServiceRequest\x1a\x1d.google.longrunning.Operation\"\xb8\x01\x88\x02\x01\xca\x41j\n5google.api.servicemanagement.v1.EnableServiceResponse\x12\x31google.api.servicemanagement.v1.OperationMetadata\xda\x41\x18service_name,consumer_id\x82\xd3\xe4\x93\x02\'\"\"/v1/services/{service_name}:enable:\x01*\x12\xa4\x02\n\x0e\x44isableService\x12\x36.google.api.servicemanagement.v1.DisableServiceRequest\x1a\x1d.google.longrunning.Operation\"\xba\x01\x88\x02\x01\xca\x41k\n6google.api.servicemanagement.v1.DisableServiceResponse\x12\x31google.api.servicemanagement.v1.OperationMetadata\xda\x41\x18service_name,consumer_id\x82\xd3\xe4\x93\x02(\"#/v1/services/{service_name}:disable:\x01*\x1a\xfd\x01\xca\x41 servicemanagement.googleapis.com\xd2\x41\xd6\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/service.management,https://www.googleapis.com/auth/service.management.readonlyB\x84\x02\n#com.google.api.servicemanagement.v1B\x13ServiceManagerProtoP\x01ZPgoogle.golang.org/genproto/googleapis/api/servicemanagement/v1;servicemanagement\xa2\x02\x04GASM\xaa\x02!Google.Cloud.ServiceManagement.V1\xca\x02!Google\\Cloud\\ServiceManagement\\V1\xea\x02$Google::Cloud::ServiceManagement::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.servicemanagement.v1.servicemanager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.google.api.servicemanagement.v1B\023ServiceManagerProtoP\001ZPgoogle.golang.org/genproto/googleapis/api/servicemanagement/v1;servicemanagement\242\002\004GASM\252\002!Google.Cloud.ServiceManagement.V1\312\002!Google\\Cloud\\ServiceManagement\\V1\352\002$Google::Cloud::ServiceManagement::V1'
  _LISTSERVICESREQUEST.fields_by_name['consumer_id']._options = None
  _LISTSERVICESREQUEST.fields_by_name['consumer_id']._serialized_options = b'\030\001'
  _GETSERVICEREQUEST.fields_by_name['service_name']._options = None
  _GETSERVICEREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _CREATESERVICEREQUEST.fields_by_name['service']._options = None
  _CREATESERVICEREQUEST.fields_by_name['service']._serialized_options = b'\342A\001\002'
  _DELETESERVICEREQUEST.fields_by_name['service_name']._options = None
  _DELETESERVICEREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _UNDELETESERVICEREQUEST.fields_by_name['service_name']._options = None
  _UNDELETESERVICEREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _GETSERVICECONFIGREQUEST.fields_by_name['service_name']._options = None
  _GETSERVICECONFIGREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _GETSERVICECONFIGREQUEST.fields_by_name['config_id']._options = None
  _GETSERVICECONFIGREQUEST.fields_by_name['config_id']._serialized_options = b'\342A\001\002'
  _LISTSERVICECONFIGSREQUEST.fields_by_name['service_name']._options = None
  _LISTSERVICECONFIGSREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _CREATESERVICECONFIGREQUEST.fields_by_name['service_name']._options = None
  _CREATESERVICECONFIGREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _CREATESERVICECONFIGREQUEST.fields_by_name['service_config']._options = None
  _CREATESERVICECONFIGREQUEST.fields_by_name['service_config']._serialized_options = b'\342A\001\002'
  _SUBMITCONFIGSOURCEREQUEST.fields_by_name['service_name']._options = None
  _SUBMITCONFIGSOURCEREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _SUBMITCONFIGSOURCEREQUEST.fields_by_name['config_source']._options = None
  _SUBMITCONFIGSOURCEREQUEST.fields_by_name['config_source']._serialized_options = b'\342A\001\002'
  _SUBMITCONFIGSOURCEREQUEST.fields_by_name['validate_only']._options = None
  _SUBMITCONFIGSOURCEREQUEST.fields_by_name['validate_only']._serialized_options = b'\342A\001\001'
  _CREATESERVICEROLLOUTREQUEST.fields_by_name['service_name']._options = None
  _CREATESERVICEROLLOUTREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _CREATESERVICEROLLOUTREQUEST.fields_by_name['rollout']._options = None
  _CREATESERVICEROLLOUTREQUEST.fields_by_name['rollout']._serialized_options = b'\342A\001\002'
  _LISTSERVICEROLLOUTSREQUEST.fields_by_name['service_name']._options = None
  _LISTSERVICEROLLOUTSREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _LISTSERVICEROLLOUTSREQUEST.fields_by_name['filter']._options = None
  _LISTSERVICEROLLOUTSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\002'
  _GETSERVICEROLLOUTREQUEST.fields_by_name['service_name']._options = None
  _GETSERVICEROLLOUTREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _GETSERVICEROLLOUTREQUEST.fields_by_name['rollout_id']._options = None
  _GETSERVICEROLLOUTREQUEST.fields_by_name['rollout_id']._serialized_options = b'\342A\001\002'
  _ENABLESERVICEREQUEST.fields_by_name['service_name']._options = None
  _ENABLESERVICEREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _ENABLESERVICEREQUEST.fields_by_name['consumer_id']._options = None
  _ENABLESERVICEREQUEST.fields_by_name['consumer_id']._serialized_options = b'\342A\001\002'
  _DISABLESERVICEREQUEST.fields_by_name['service_name']._options = None
  _DISABLESERVICEREQUEST.fields_by_name['service_name']._serialized_options = b'\342A\001\002'
  _DISABLESERVICEREQUEST.fields_by_name['consumer_id']._options = None
  _DISABLESERVICEREQUEST.fields_by_name['consumer_id']._serialized_options = b'\342A\001\002'
  _GENERATECONFIGREPORTREQUEST.fields_by_name['new_config']._options = None
  _GENERATECONFIGREPORTREQUEST.fields_by_name['new_config']._serialized_options = b'\342A\001\002'
  _GENERATECONFIGREPORTREQUEST.fields_by_name['old_config']._options = None
  _GENERATECONFIGREPORTREQUEST.fields_by_name['old_config']._serialized_options = b'\342A\001\001'
  _SERVICEMANAGER._options = None
  _SERVICEMANAGER._serialized_options = b'\312A servicemanagement.googleapis.com\322A\326\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/service.management,https://www.googleapis.com/auth/service.management.readonly'
  _SERVICEMANAGER.methods_by_name['ListServices']._options = None
  _SERVICEMANAGER.methods_by_name['ListServices']._serialized_options = b'\332A\037producer_project_id,consumer_id\202\323\344\223\002\016\022\014/v1/services'
  _SERVICEMANAGER.methods_by_name['GetService']._options = None
  _SERVICEMANAGER.methods_by_name['GetService']._serialized_options = b'\332A\014service_name\202\323\344\223\002\035\022\033/v1/services/{service_name}'
  _SERVICEMANAGER.methods_by_name['CreateService']._options = None
  _SERVICEMANAGER.methods_by_name['CreateService']._serialized_options = b'\312Ac\n.google.api.servicemanagement.v1.ManagedService\0221google.api.servicemanagement.v1.OperationMetadata\332A\007service\202\323\344\223\002\027\"\014/v1/services:\007service'
  _SERVICEMANAGER.methods_by_name['DeleteService']._options = None
  _SERVICEMANAGER.methods_by_name['DeleteService']._serialized_options = b'\312AJ\n\025google.protobuf.Empty\0221google.api.servicemanagement.v1.OperationMetadata\332A\014service_name\202\323\344\223\002\035*\033/v1/services/{service_name}'
  _SERVICEMANAGER.methods_by_name['UndeleteService']._options = None
  _SERVICEMANAGER.methods_by_name['UndeleteService']._serialized_options = b'\312Al\n7google.api.servicemanagement.v1.UndeleteServiceResponse\0221google.api.servicemanagement.v1.OperationMetadata\332A\014service_name\202\323\344\223\002&\"$/v1/services/{service_name}:undelete'
  _SERVICEMANAGER.methods_by_name['ListServiceConfigs']._options = None
  _SERVICEMANAGER.methods_by_name['ListServiceConfigs']._serialized_options = b'\332A\014service_name\202\323\344\223\002%\022#/v1/services/{service_name}/configs'
  _SERVICEMANAGER.methods_by_name['GetServiceConfig']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceConfig']._serialized_options = b'\332A\033service_name,config_id,view\202\323\344\223\002W\022//v1/services/{service_name}/configs/{config_id}Z$\022\"/v1/services/{service_name}/config'
  _SERVICEMANAGER.methods_by_name['CreateServiceConfig']._options = None
  _SERVICEMANAGER.methods_by_name['CreateServiceConfig']._serialized_options = b'\332A\033service_name,service_config\202\323\344\223\0025\"#/v1/services/{service_name}/configs:\016service_config'
  _SERVICEMANAGER.methods_by_name['SubmitConfigSource']._options = None
  _SERVICEMANAGER.methods_by_name['SubmitConfigSource']._serialized_options = b'\312Ao\n:google.api.servicemanagement.v1.SubmitConfigSourceResponse\0221google.api.servicemanagement.v1.OperationMetadata\332A(service_name,config_source,validate_only\202\323\344\223\002/\"*/v1/services/{service_name}/configs:submit:\001*'
  _SERVICEMANAGER.methods_by_name['ListServiceRollouts']._options = None
  _SERVICEMANAGER.methods_by_name['ListServiceRollouts']._serialized_options = b'\332A\023service_name,filter\202\323\344\223\002&\022$/v1/services/{service_name}/rollouts'
  _SERVICEMANAGER.methods_by_name['GetServiceRollout']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceRollout']._serialized_options = b'\332A\027service_name,rollout_id\202\323\344\223\0023\0221/v1/services/{service_name}/rollouts/{rollout_id}'
  _SERVICEMANAGER.methods_by_name['CreateServiceRollout']._options = None
  _SERVICEMANAGER.methods_by_name['CreateServiceRollout']._serialized_options = b'\312A\\\n\'google.api.servicemanagement.v1.Rollout\0221google.api.servicemanagement.v1.OperationMetadata\332A\024service_name,rollout\202\323\344\223\002/\"$/v1/services/{service_name}/rollouts:\007rollout'
  _SERVICEMANAGER.methods_by_name['GenerateConfigReport']._options = None
  _SERVICEMANAGER.methods_by_name['GenerateConfigReport']._serialized_options = b'\332A\025new_config,old_config\202\323\344\223\002&\"!/v1/services:generateConfigReport:\001*'
  _SERVICEMANAGER.methods_by_name['EnableService']._options = None
  _SERVICEMANAGER.methods_by_name['EnableService']._serialized_options = b'\210\002\001\312Aj\n5google.api.servicemanagement.v1.EnableServiceResponse\0221google.api.servicemanagement.v1.OperationMetadata\332A\030service_name,consumer_id\202\323\344\223\002\'\"\"/v1/services/{service_name}:enable:\001*'
  _SERVICEMANAGER.methods_by_name['DisableService']._options = None
  _SERVICEMANAGER.methods_by_name['DisableService']._serialized_options = b'\210\002\001\312Ak\n6google.api.servicemanagement.v1.DisableServiceResponse\0221google.api.servicemanagement.v1.OperationMetadata\332A\030service_name,consumer_id\202\323\344\223\002(\"#/v1/services/{service_name}:disable:\001*'
  _globals['_LISTSERVICESREQUEST']._serialized_start=375
  _globals['_LISTSERVICESREQUEST']._serialized_end=489
  _globals['_LISTSERVICESRESPONSE']._serialized_start=491
  _globals['_LISTSERVICESRESPONSE']._serialized_end=605
  _globals['_GETSERVICEREQUEST']._serialized_start=607
  _globals['_GETSERVICEREQUEST']._serialized_end=654
  _globals['_CREATESERVICEREQUEST']._serialized_start=656
  _globals['_CREATESERVICEREQUEST']._serialized_end=750
  _globals['_DELETESERVICEREQUEST']._serialized_start=752
  _globals['_DELETESERVICEREQUEST']._serialized_end=802
  _globals['_UNDELETESERVICEREQUEST']._serialized_start=804
  _globals['_UNDELETESERVICEREQUEST']._serialized_end=856
  _globals['_UNDELETESERVICERESPONSE']._serialized_start=858
  _globals['_UNDELETESERVICERESPONSE']._serialized_end=949
  _globals['_GETSERVICECONFIGREQUEST']._serialized_start=952
  _globals['_GETSERVICECONFIGREQUEST']._serialized_end=1148
  _globals['_GETSERVICECONFIGREQUEST_CONFIGVIEW']._serialized_start=1115
  _globals['_GETSERVICECONFIGREQUEST_CONFIGVIEW']._serialized_end=1148
  _globals['_LISTSERVICECONFIGSREQUEST']._serialized_start=1150
  _globals['_LISTSERVICECONFIGSREQUEST']._serialized_end=1244
  _globals['_LISTSERVICECONFIGSRESPONSE']._serialized_start=1246
  _globals['_LISTSERVICECONFIGSRESPONSE']._serialized_end=1345
  _globals['_CREATESERVICECONFIGREQUEST']._serialized_start=1347
  _globals['_CREATESERVICECONFIGREQUEST']._serialized_end=1454
  _globals['_SUBMITCONFIGSOURCEREQUEST']._serialized_start=1457
  _globals['_SUBMITCONFIGSOURCEREQUEST']._serialized_end=1617
  _globals['_SUBMITCONFIGSOURCERESPONSE']._serialized_start=1619
  _globals['_SUBMITCONFIGSOURCERESPONSE']._serialized_end=1692
  _globals['_CREATESERVICEROLLOUTREQUEST']._serialized_start=1694
  _globals['_CREATESERVICEROLLOUTREQUEST']._serialized_end=1816
  _globals['_LISTSERVICEROLLOUTSREQUEST']._serialized_start=1818
  _globals['_LISTSERVICEROLLOUTSREQUEST']._serialized_end=1935
  _globals['_LISTSERVICEROLLOUTSRESPONSE']._serialized_start=1937
  _globals['_LISTSERVICEROLLOUTSRESPONSE']._serialized_end=2051
  _globals['_GETSERVICEROLLOUTREQUEST']._serialized_start=2053
  _globals['_GETSERVICEROLLOUTREQUEST']._serialized_end=2133
  _globals['_ENABLESERVICEREQUEST']._serialized_start=2135
  _globals['_ENABLESERVICEREQUEST']._serialized_end=2212
  _globals['_ENABLESERVICERESPONSE']._serialized_start=2214
  _globals['_ENABLESERVICERESPONSE']._serialized_end=2237
  _globals['_DISABLESERVICEREQUEST']._serialized_start=2239
  _globals['_DISABLESERVICEREQUEST']._serialized_end=2317
  _globals['_DISABLESERVICERESPONSE']._serialized_start=2319
  _globals['_DISABLESERVICERESPONSE']._serialized_end=2343
  _globals['_GENERATECONFIGREPORTREQUEST']._serialized_start=2345
  _globals['_GENERATECONFIGREPORTREQUEST']._serialized_end=2470
  _globals['_GENERATECONFIGREPORTRESPONSE']._serialized_start=2473
  _globals['_GENERATECONFIGREPORTRESPONSE']._serialized_end=2674
  _globals['_SERVICEMANAGER']._serialized_start=2677
  _globals['_SERVICEMANAGER']._serialized_end=6535
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/struct.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import value_pb2 as envoy_dot_type_dot_matcher_dot_value__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/type/matcher/struct.proto\x12\x12\x65nvoy.type.matcher\x1a\x1e\x65nvoy/type/matcher/value.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x01\n\rStructMatcher\x12\x45\n\x04path\x18\x02 \x03(\x0b\x32-.envoy.type.matcher.StructMatcher.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x39\n\x05value\x18\x03 \x01(\x0b\x32 .envoy.type.matcher.ValueMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\x35\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x42\x0e\n\x07segment\x12\x03\xf8\x42\x01\x42t\n io.envoyproxy.envoy.type.matcherB\x0bStructProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.struct_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.type.matcherB\013StructProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\272\200\310\321\006\002\020\001'
  _STRUCTMATCHER_PATHSEGMENT.oneofs_by_name['segment']._options = None
  _STRUCTMATCHER_PATHSEGMENT.oneofs_by_name['segment']._serialized_options = b'\370B\001'
  _STRUCTMATCHER_PATHSEGMENT.fields_by_name['key']._options = None
  _STRUCTMATCHER_PATHSEGMENT.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _STRUCTMATCHER.fields_by_name['path']._options = None
  _STRUCTMATCHER.fields_by_name['path']._serialized_options = b'\372B\005\222\001\002\010\001'
  _STRUCTMATCHER.fields_by_name['value']._options = None
  _STRUCTMATCHER.fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STRUCTMATCHER']._serialized_start=144
  _globals['_STRUCTMATCHER']._serialized_end=344
  _globals['_STRUCTMATCHER_PATHSEGMENT']._serialized_start=291
  _globals['_STRUCTMATCHER_PATHSEGMENT']._serialized_end=344
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/http_uri.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/core/v3/http_uri.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x01\n\x07HttpUri\x12\x14\n\x03uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\x07\x63luster\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x36\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01\x32\x00: \x9a\xc5\x88\x1e\x1b\n\x19\x65nvoy.api.v2.core.HttpUriB\x19\n\x12http_upstream_type\x12\x03\xf8\x42\x01\x42\x80\x01\n\"io.envoyproxy.envoy.config.core.v3B\x0cHttpUriProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.http_uri_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\014HttpUriProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _HTTPURI.oneofs_by_name['http_upstream_type']._options = None
  _HTTPURI.oneofs_by_name['http_upstream_type']._serialized_options = b'\370B\001'
  _HTTPURI.fields_by_name['uri']._options = None
  _HTTPURI.fields_by_name['uri']._serialized_options = b'\372B\004r\002\020\001'
  _HTTPURI.fields_by_name['cluster']._options = None
  _HTTPURI.fields_by_name['cluster']._serialized_options = b'\372B\004r\002\020\001'
  _HTTPURI.fields_by_name['timeout']._options = None
  _HTTPURI.fields_by_name['timeout']._serialized_options = b'\372B\007\252\001\004\010\0012\000'
  _HTTPURI._options = None
  _HTTPURI._serialized_options = b'\232\305\210\036\033\n\031envoy.api.v2.core.HttpUri'
  _globals['_HTTPURI']._serialized_start=185
  _globals['_HTTPURI']._serialized_end=361
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v3/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import circuit_breaker_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_circuit__breaker__pb2
from envoy.config.cluster.v3 import filter_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_filter__pb2
from envoy.config.cluster.v3 import outlier_detection_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_outlier__detection__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import health_check_pb2 as envoy_dot_config_dot_core_dot_v3_dot_health__check__pb2
from envoy.config.core.v3 import protocol_pb2 as envoy_dot_config_dot_core_dot_v3_dot_protocol__pb2
from envoy.config.core.v3 import resolver_pb2 as envoy_dot_config_dot_core_dot_v3_dot_resolver__pb2
from envoy.config.endpoint.v3 import endpoint_pb2 as envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.core.v3 import collection_entry_pb2 as xds_dot_core_dot_v3_dot_collection__entry__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import security_pb2 as udpa_dot_annotations_dot_security__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/config/cluster/v3/cluster.proto\x12\x17\x65nvoy.config.cluster.v3\x1a-envoy/config/cluster/v3/circuit_breaker.proto\x1a$envoy/config/cluster/v3/filter.proto\x1a/envoy/config/cluster/v3/outlier_detection.proto\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a$envoy/config/core/v3/extension.proto\x1a\'envoy/config/core/v3/health_check.proto\x1a#envoy/config/core/v3/protocol.proto\x1a#envoy/config/core/v3/resolver.proto\x1a\'envoy/config/endpoint/v3/endpoint.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\"xds/core/v3/collection_entry.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1fudpa/annotations/security.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"B\n\x11\x43lusterCollection\x12-\n\x07\x65ntries\x18\x01 \x01(\x0b\x32\x1c.xds.core.v3.CollectionEntry\"\xfe\x43\n\x07\x43luster\x12W\n\x18transport_socket_matches\x18+ \x03(\x0b\x32\x35.envoy.config.cluster.v3.Cluster.TransportSocketMatch\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x31\n\ralt_stat_name\x18\x1c \x01(\tB\x1a\xf2\x98\xfe\x8f\x05\x14\n\x12observability_name\x12H\n\x04type\x18\x02 \x01(\x0e\x32..envoy.config.cluster.v3.Cluster.DiscoveryTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01H\x00\x12J\n\x0c\x63luster_type\x18& \x01(\x0b\x32\x32.envoy.config.cluster.v3.Cluster.CustomClusterTypeH\x00\x12M\n\x12\x65\x64s_cluster_config\x18\x03 \x01(\x0b\x32\x31.envoy.config.cluster.v3.Cluster.EdsClusterConfig\x12<\n\x0f\x63onnect_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12P\n!per_connection_buffer_limit_bytes\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\x8a\x93\xb7*\x02\x10\x01\x12\x46\n\tlb_policy\x18\x06 \x01(\x0e\x32).envoy.config.cluster.v3.Cluster.LbPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12H\n\x0fload_assignment\x18! \x01(\x0b\x32/.envoy.config.endpoint.v3.ClusterLoadAssignment\x12\x38\n\rhealth_checks\x18\x08 \x03(\x0b\x32!.envoy.config.core.v3.HealthCheck\x12N\n\x1bmax_requests_per_connection\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x42\n\x10\x63ircuit_breakers\x18\n \x01(\x0b\x32(.envoy.config.cluster.v3.CircuitBreakers\x12\x66\n\x1eupstream_http_protocol_options\x18. \x01(\x0b\x32\x31.envoy.config.core.v3.UpstreamHttpProtocolOptionsB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\\\n\x1c\x63ommon_http_protocol_options\x18\x1d \x01(\x0b\x32).envoy.config.core.v3.HttpProtocolOptionsB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12V\n\x15http_protocol_options\x18\r \x01(\x0b\x32*.envoy.config.core.v3.Http1ProtocolOptionsB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12^\n\x16http2_protocol_options\x18\x0e \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptionsB\x12\x18\x01\x8a\x93\xb7*\x02\x10\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12m\n typed_extension_protocol_options\x18$ \x03(\x0b\x32\x43.envoy.config.cluster.v3.Cluster.TypedExtensionProtocolOptionsEntry\x12\x41\n\x10\x64ns_refresh_rate\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06*\x04\x10\xc0\x84=\x12N\n\x18\x64ns_failure_refresh_rate\x18, \x01(\x0b\x32,.envoy.config.cluster.v3.Cluster.RefreshRate\x12\x17\n\x0frespect_dns_ttl\x18\' \x01(\x08\x12U\n\x11\x64ns_lookup_family\x18\x11 \x01(\x0e\x32\x30.envoy.config.cluster.v3.Cluster.DnsLookupFamilyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\rdns_resolvers\x18\x12 \x03(\x0b\x32\x1d.envoy.config.core.v3.AddressB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12,\n\x17use_tcp_for_dns_lookups\x18- \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12U\n\x15\x64ns_resolution_config\x18\x35 \x01(\x0b\x32).envoy.config.core.v3.DnsResolutionConfigB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12M\n\x19typed_dns_resolver_config\x18\x37 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12\x39\n\x15wait_for_warm_on_init\x18\x36 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x44\n\x11outlier_detection\x18\x13 \x01(\x0b\x32).envoy.config.cluster.v3.OutlierDetection\x12=\n\x10\x63leanup_interval\x18\x14 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12>\n\x14upstream_bind_config\x18\x15 \x01(\x0b\x32 .envoy.config.core.v3.BindConfig\x12I\n\x10lb_subset_config\x18\x16 \x01(\x0b\x32/.envoy.config.cluster.v3.Cluster.LbSubsetConfig\x12P\n\x13ring_hash_lb_config\x18\x17 \x01(\x0b\x32\x31.envoy.config.cluster.v3.Cluster.RingHashLbConfigH\x01\x12K\n\x10maglev_lb_config\x18\x34 \x01(\x0b\x32/.envoy.config.cluster.v3.Cluster.MaglevLbConfigH\x01\x12V\n\x16original_dst_lb_config\x18\" \x01(\x0b\x32\x34.envoy.config.cluster.v3.Cluster.OriginalDstLbConfigH\x01\x12X\n\x17least_request_lb_config\x18% \x01(\x0b\x32\x35.envoy.config.cluster.v3.Cluster.LeastRequestLbConfigH\x01\x12T\n\x15round_robin_lb_config\x18\x38 \x01(\x0b\x32\x33.envoy.config.cluster.v3.Cluster.RoundRobinLbConfigH\x01\x12I\n\x10\x63ommon_lb_config\x18\x1b \x01(\x0b\x32/.envoy.config.cluster.v3.Cluster.CommonLbConfig\x12?\n\x10transport_socket\x18\x18 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocket\x12\x30\n\x08metadata\x18\x19 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12\x62\n\x12protocol_selection\x18\x1a \x01(\x0e\x32\x39.envoy.config.cluster.v3.Cluster.ClusterProtocolSelectionB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12W\n\x1bupstream_connection_options\x18\x1e \x01(\x0b\x32\x32.envoy.config.cluster.v3.UpstreamConnectionOptions\x12\x30\n(close_connections_on_host_health_failure\x18\x1f \x01(\x08\x12%\n\x1dignore_health_on_host_removal\x18  \x01(\x08\x12\x30\n\x07\x66ilters\x18( \x03(\x0b\x32\x1f.envoy.config.cluster.v3.Filter\x12K\n\x15load_balancing_policy\x18) \x01(\x0b\x32,.envoy.config.cluster.v3.LoadBalancingPolicy\x12\x36\n\nlrs_server\x18* \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12*\n\x15track_timeout_budgets\x18/ \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x43\n\x0fupstream_config\x18\x30 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12G\n\x13track_cluster_stats\x18\x31 \x01(\x0b\x32*.envoy.config.cluster.v3.TrackClusterStats\x12L\n\x11preconnect_policy\x18\x32 \x01(\x0b\x32\x31.envoy.config.cluster.v3.Cluster.PreconnectPolicy\x12\x31\n)connection_pool_per_downstream_connection\x18\x33 \x01(\x08\x1a\xc8\x01\n\x14TransportSocketMatch\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12&\n\x05match\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12?\n\x10transport_socket\x18\x03 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocket:0\x9a\xc5\x88\x1e+\n)envoy.api.v2.Cluster.TransportSocketMatch\x1a\x85\x01\n\x11\x43ustomClusterType\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12*\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.Cluster.CustomClusterType\x1a\x8e\x01\n\x10\x45\x64sClusterConfig\x12\x36\n\neds_config\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12\x14\n\x0cservice_name\x18\x02 \x01(\t:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.Cluster.EdsClusterConfig\x1a\xd9\x08\n\x0eLbSubsetConfig\x12i\n\x0f\x66\x61llback_policy\x18\x01 \x01(\x0e\x32\x46.envoy.config.cluster.v3.Cluster.LbSubsetConfig.LbSubsetFallbackPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12/\n\x0e\x64\x65\x66\x61ult_subset\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Z\n\x10subset_selectors\x18\x03 \x03(\x0b\x32@.envoy.config.cluster.v3.Cluster.LbSubsetConfig.LbSubsetSelector\x12\x1d\n\x15locality_weight_aware\x18\x04 \x01(\x08\x12\x1d\n\x15scale_locality_weight\x18\x05 \x01(\x08\x12\x16\n\x0epanic_mode_any\x18\x06 \x01(\x08\x12\x13\n\x0blist_as_any\x18\x07 \x01(\x08\x12z\n\x18metadata_fallback_policy\x18\x08 \x01(\x0e\x32N.envoy.config.cluster.v3.Cluster.LbSubsetConfig.LbSubsetMetadataFallbackPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x1a\x9b\x03\n\x10LbSubsetSelector\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12\x1e\n\x16single_host_per_subset\x18\x04 \x01(\x08\x12\x82\x01\n\x0f\x66\x61llback_policy\x18\x02 \x01(\x0e\x32_.envoy.config.cluster.v3.Cluster.LbSubsetConfig.LbSubsetSelector.LbSubsetSelectorFallbackPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x14\x66\x61llback_keys_subset\x18\x03 \x03(\t\"y\n\x1eLbSubsetSelectorFallbackPolicy\x12\x0f\n\x0bNOT_DEFINED\x10\x00\x12\x0f\n\x0bNO_FALLBACK\x10\x01\x12\x10\n\x0c\x41NY_ENDPOINT\x10\x02\x12\x12\n\x0e\x44\x45\x46\x41ULT_SUBSET\x10\x03\x12\x0f\n\x0bKEYS_SUBSET\x10\x04:;\x9a\xc5\x88\x1e\x36\n4envoy.api.v2.Cluster.LbSubsetConfig.LbSubsetSelector\"O\n\x16LbSubsetFallbackPolicy\x12\x0f\n\x0bNO_FALLBACK\x10\x00\x12\x10\n\x0c\x41NY_ENDPOINT\x10\x01\x12\x12\n\x0e\x44\x45\x46\x41ULT_SUBSET\x10\x02\"M\n\x1eLbSubsetMetadataFallbackPolicy\x12\x18\n\x14METADATA_NO_FALLBACK\x10\x00\x12\x11\n\rFALLBACK_LIST\x10\x01:*\x9a\xc5\x88\x1e%\n#envoy.api.v2.Cluster.LbSubsetConfig\x1a\xb4\x01\n\x0fSlowStartConfig\x12\x34\n\x11slow_start_window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\naggression\x18\x02 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeDouble\x12\x32\n\x12min_weight_percent\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x1a\x61\n\x12RoundRobinLbConfig\x12K\n\x11slow_start_config\x18\x01 \x01(\x0b\x32\x30.envoy.config.cluster.v3.Cluster.SlowStartConfig\x1a\x94\x02\n\x14LeastRequestLbConfig\x12;\n\x0c\x63hoice_count\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x02\x12@\n\x13\x61\x63tive_request_bias\x18\x02 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeDouble\x12K\n\x11slow_start_config\x18\x03 \x01(\x0b\x32\x30.envoy.config.cluster.v3.Cluster.SlowStartConfig:0\x9a\xc5\x88\x1e+\n)envoy.api.v2.Cluster.LeastRequestLbConfig\x1a\xe1\x02\n\x10RingHashLbConfig\x12\x43\n\x11minimum_ring_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\n\xfa\x42\x07\x32\x05\x18\x80\x80\x80\x04\x12_\n\rhash_function\x18\x03 \x01(\x0e\x32>.envoy.config.cluster.v3.Cluster.RingHashLbConfig.HashFunctionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x43\n\x11maximum_ring_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\n\xfa\x42\x07\x32\x05\x18\x80\x80\x80\x04\".\n\x0cHashFunction\x12\x0b\n\x07XX_HASH\x10\x00\x12\x11\n\rMURMUR_HASH_2\x10\x01:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.Cluster.RingHashLbConfigJ\x04\x08\x02\x10\x03\x1aN\n\x0eMaglevLbConfig\x12<\n\ntable_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\n\xfa\x42\x07\x32\x05\x18\xcb\x96\xb1\x02\x1a\xc2\x01\n\x13OriginalDstLbConfig\x12\x17\n\x0fuse_http_header\x18\x01 \x01(\x08\x12\x18\n\x10http_header_name\x18\x02 \x01(\t\x12G\n\x16upstream_port_override\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\xff\xff\x03:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.Cluster.OriginalDstLbConfig\x1a\xb2\t\n\x0e\x43ommonLbConfig\x12\x37\n\x17healthy_panic_threshold\x18\x01 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x61\n\x14zone_aware_lb_config\x18\x02 \x01(\x0b\x32\x41.envoy.config.cluster.v3.Cluster.CommonLbConfig.ZoneAwareLbConfigH\x00\x12o\n\x1blocality_weighted_lb_config\x18\x03 \x01(\x0b\x32H.envoy.config.cluster.v3.Cluster.CommonLbConfig.LocalityWeightedLbConfigH\x00\x12\x36\n\x13update_merge_window\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\'\n\x1fignore_new_hosts_until_first_hc\x18\x05 \x01(\x08\x12,\n$close_connections_on_host_set_change\x18\x06 \x01(\x08\x12o\n\x1c\x63onsistent_hashing_lb_config\x18\x07 \x01(\x0b\x32I.envoy.config.cluster.v3.Cluster.CommonLbConfig.ConsistentHashingLbConfig\x12\x43\n\x14override_host_status\x18\x08 \x01(\x0b\x32%.envoy.config.core.v3.HealthStatusSet\x1a\xd9\x01\n\x11ZoneAwareLbConfig\x12/\n\x0frouting_enabled\x18\x01 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x36\n\x10min_cluster_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x15\x66\x61il_traffic_on_panic\x18\x03 \x01(\x08:<\x9a\xc5\x88\x1e\x37\n5envoy.api.v2.Cluster.CommonLbConfig.ZoneAwareLbConfig\x1a_\n\x18LocalityWeightedLbConfig:C\x9a\xc5\x88\x1e>\n<envoy.api.v2.Cluster.CommonLbConfig.LocalityWeightedLbConfig\x1a\xc7\x01\n\x19\x43onsistentHashingLbConfig\x12 \n\x18use_hostname_for_hashing\x18\x01 \x01(\x08\x12\x42\n\x13hash_balance_factor\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(d:D\x9a\xc5\x88\x1e?\n=envoy.api.v2.Cluster.CommonLbConfig.ConsistentHashingLbConfig:*\x9a\xc5\x88\x1e%\n#envoy.api.v2.Cluster.CommonLbConfigB\x1b\n\x19locality_config_specifier\x1a\xb7\x01\n\x0bRefreshRate\x12@\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01*\x04\x10\xc0\x84=\x12=\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06*\x04\x10\xc0\x84=:\'\x9a\xc5\x88\x1e\"\n envoy.api.v2.Cluster.RefreshRate\x1a\xcc\x01\n\x10PreconnectPolicy\x12\\\n\x1dper_upstream_preconnect_ratio\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\x08@)\x00\x00\x00\x00\x00\x00\xf0?\x12Z\n\x1bpredictive_preconnect_ratio\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\x08@)\x00\x00\x00\x00\x00\x00\xf0?\x1aZ\n\"TypedExtensionProtocolOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\"W\n\rDiscoveryType\x12\n\n\x06STATIC\x10\x00\x12\x0e\n\nSTRICT_DNS\x10\x01\x12\x0f\n\x0bLOGICAL_DNS\x10\x02\x12\x07\n\x03\x45\x44S\x10\x03\x12\x10\n\x0cORIGINAL_DST\x10\x04\"\xa4\x01\n\x08LbPolicy\x12\x0f\n\x0bROUND_ROBIN\x10\x00\x12\x11\n\rLEAST_REQUEST\x10\x01\x12\r\n\tRING_HASH\x10\x02\x12\n\n\x06RANDOM\x10\x03\x12\n\n\x06MAGLEV\x10\x05\x12\x14\n\x10\x43LUSTER_PROVIDED\x10\x06\x12 \n\x1cLOAD_BALANCING_POLICY_CONFIG\x10\x07\"\x04\x08\x04\x10\x04*\x0fORIGINAL_DST_LB\"P\n\x0f\x44nsLookupFamily\x12\x08\n\x04\x41UTO\x10\x00\x12\x0b\n\x07V4_ONLY\x10\x01\x12\x0b\n\x07V6_ONLY\x10\x02\x12\x10\n\x0cV4_PREFERRED\x10\x03\x12\x07\n\x03\x41LL\x10\x04\"T\n\x18\x43lusterProtocolSelection\x12\x1b\n\x17USE_CONFIGURED_PROTOCOL\x10\x00\x12\x1b\n\x17USE_DOWNSTREAM_PROTOCOL\x10\x01:\x1b\x9a\xc5\x88\x1e\x16\n\x14\x65nvoy.api.v2.ClusterB\x18\n\x16\x63luster_discovery_typeB\x0b\n\tlb_configJ\x04\x08\x0c\x10\rJ\x04\x08\x0f\x10\x10J\x04\x08\x07\x10\x08J\x04\x08\x0b\x10\x0cJ\x04\x08#\x10$R\x05hostsR\x0btls_contextR\x1a\x65xtension_protocol_options\"\xba\x02\n\x13LoadBalancingPolicy\x12\x45\n\x08policies\x18\x01 \x03(\x0b\x32\x33.envoy.config.cluster.v3.LoadBalancingPolicy.Policy\x1a\xb2\x01\n\x06Policy\x12J\n\x16typed_extension_config\x18\x04 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig:.\x9a\xc5\x88\x1e)\n\'envoy.api.v2.LoadBalancingPolicy.PolicyJ\x04\x08\x02\x10\x03J\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04R\x06\x63onfigR\x04nameR\x0ctyped_config:\'\x9a\xc5\x88\x1e\"\n envoy.api.v2.LoadBalancingPolicy\"\xbf\x01\n\x19UpstreamConnectionOptions\x12\x39\n\rtcp_keepalive\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.TcpKeepalive\x12\x38\n0set_local_interface_name_on_upstream_connections\x18\x02 \x01(\x08:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.UpstreamConnectionOptions\"L\n\x11TrackClusterStats\x12\x17\n\x0ftimeout_budgets\x18\x01 \x01(\x08\x12\x1e\n\x16request_response_sizes\x18\x02 \x01(\x08\x42\x89\x01\n%io.envoyproxy.envoy.config.cluster.v3B\x0c\x43lusterProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.cluster.v3.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.config.cluster.v3B\014ClusterProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\272\200\310\321\006\002\020\002'
  _CLUSTER_TRANSPORTSOCKETMATCH.fields_by_name['name']._options = None
  _CLUSTER_TRANSPORTSOCKETMATCH.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTER_TRANSPORTSOCKETMATCH._options = None
  _CLUSTER_TRANSPORTSOCKETMATCH._serialized_options = b'\232\305\210\036+\n)envoy.api.v2.Cluster.TransportSocketMatch'
  _CLUSTER_CUSTOMCLUSTERTYPE.fields_by_name['name']._options = None
  _CLUSTER_CUSTOMCLUSTERTYPE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTER_CUSTOMCLUSTERTYPE._options = None
  _CLUSTER_CUSTOMCLUSTERTYPE._serialized_options = b'\232\305\210\036(\n&envoy.api.v2.Cluster.CustomClusterType'
  _CLUSTER_EDSCLUSTERCONFIG._options = None
  _CLUSTER_EDSCLUSTERCONFIG._serialized_options = b'\232\305\210\036\'\n%envoy.api.v2.Cluster.EdsClusterConfig'
  _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR.fields_by_name['fallback_policy']._options = None
  _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR.fields_by_name['fallback_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR._options = None
  _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR._serialized_options = b'\232\305\210\0366\n4envoy.api.v2.Cluster.LbSubsetConfig.LbSubsetSelector'
  _CLUSTER_LBSUBSETCONFIG.fields_by_name['fallback_policy']._options = None
  _CLUSTER_LBSUBSETCONFIG.fields_by_name['fallback_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER_LBSUBSETCONFIG.fields_by_name['metadata_fallback_policy']._options = None
  _CLUSTER_LBSUBSETCONFIG.fields_by_name['metadata_fallback_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER_LBSUBSETCONFIG._options = None
  _CLUSTER_LBSUBSETCONFIG._serialized_options = b'\232\305\210\036%\n#envoy.api.v2.Cluster.LbSubsetConfig'
  _CLUSTER_LEASTREQUESTLBCONFIG.fields_by_name['choice_count']._options = None
  _CLUSTER_LEASTREQUESTLBCONFIG.fields_by_name['choice_count']._serialized_options = b'\372B\004*\002(\002'
  _CLUSTER_LEASTREQUESTLBCONFIG._options = None
  _CLUSTER_LEASTREQUESTLBCONFIG._serialized_options = b'\232\305\210\036+\n)envoy.api.v2.Cluster.LeastRequestLbConfig'
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['minimum_ring_size']._options = None
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['minimum_ring_size']._serialized_options = b'\372B\0072\005\030\200\200\200\004'
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['hash_function']._options = None
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['hash_function']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['maximum_ring_size']._options = None
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['maximum_ring_size']._serialized_options = b'\372B\0072\005\030\200\200\200\004'
  _CLUSTER_RINGHASHLBCONFIG._options = None
  _CLUSTER_RINGHASHLBCONFIG._serialized_options = b'\232\305\210\036\'\n%envoy.api.v2.Cluster.RingHashLbConfig'
  _CLUSTER_MAGLEVLBCONFIG.fields_by_name['table_size']._options = None
  _CLUSTER_MAGLEVLBCONFIG.fields_by_name['table_size']._serialized_options = b'\372B\0072\005\030\313\226\261\002'
  _CLUSTER_ORIGINALDSTLBCONFIG.fields_by_name['upstream_port_override']._options = None
  _CLUSTER_ORIGINALDSTLBCONFIG.fields_by_name['upstream_port_override']._serialized_options = b'\372B\006*\004\030\377\377\003'
  _CLUSTER_ORIGINALDSTLBCONFIG._options = None
  _CLUSTER_ORIGINALDSTLBCONFIG._serialized_options = b'\232\305\210\036*\n(envoy.api.v2.Cluster.OriginalDstLbConfig'
  _CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG._options = None
  _CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG._serialized_options = b'\232\305\210\0367\n5envoy.api.v2.Cluster.CommonLbConfig.ZoneAwareLbConfig'
  _CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG._options = None
  _CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG._serialized_options = b'\232\305\210\036>\n<envoy.api.v2.Cluster.CommonLbConfig.LocalityWeightedLbConfig'
  _CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG.fields_by_name['hash_balance_factor']._options = None
  _CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG.fields_by_name['hash_balance_factor']._serialized_options = b'\372B\004*\002(d'
  _CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG._options = None
  _CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG._serialized_options = b'\232\305\210\036?\n=envoy.api.v2.Cluster.CommonLbConfig.ConsistentHashingLbConfig'
  _CLUSTER_COMMONLBCONFIG._options = None
  _CLUSTER_COMMONLBCONFIG._serialized_options = b'\232\305\210\036%\n#envoy.api.v2.Cluster.CommonLbConfig'
  _CLUSTER_REFRESHRATE.fields_by_name['base_interval']._options = None
  _CLUSTER_REFRESHRATE.fields_by_name['base_interval']._serialized_options = b'\372B\013\252\001\010\010\001*\004\020\300\204='
  _CLUSTER_REFRESHRATE.fields_by_name['max_interval']._options = None
  _CLUSTER_REFRESHRATE.fields_by_name['max_interval']._serialized_options = b'\372B\t\252\001\006*\004\020\300\204='
  _CLUSTER_REFRESHRATE._options = None
  _CLUSTER_REFRESHRATE._serialized_options = b'\232\305\210\036\"\n envoy.api.v2.Cluster.RefreshRate'
  _CLUSTER_PRECONNECTPOLICY.fields_by_name['per_upstream_preconnect_ratio']._options = None
  _CLUSTER_PRECONNECTPOLICY.fields_by_name['per_upstream_preconnect_ratio']._serialized_options = b'\372B\024\022\022\031\000\000\000\000\000\000\010@)\000\000\000\000\000\000\360?'
  _CLUSTER_PRECONNECTPOLICY.fields_by_name['predictive_preconnect_ratio']._options = None
  _CLUSTER_PRECONNECTPOLICY.fields_by_name['predictive_preconnect_ratio']._serialized_options = b'\372B\024\022\022\031\000\000\000\000\000\000\010@)\000\000\000\000\000\000\360?'
  _CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY._options = None
  _CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY._serialized_options = b'8\001'
  _CLUSTER.fields_by_name['name']._options = None
  _CLUSTER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTER.fields_by_name['alt_stat_name']._options = None
  _CLUSTER.fields_by_name['alt_stat_name']._serialized_options = b'\362\230\376\217\005\024\n\022observability_name'
  _CLUSTER.fields_by_name['type']._options = None
  _CLUSTER.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER.fields_by_name['connect_timeout']._options = None
  _CLUSTER.fields_by_name['connect_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _CLUSTER.fields_by_name['per_connection_buffer_limit_bytes']._options = None
  _CLUSTER.fields_by_name['per_connection_buffer_limit_bytes']._serialized_options = b'\212\223\267*\002\020\001'
  _CLUSTER.fields_by_name['lb_policy']._options = None
  _CLUSTER.fields_by_name['lb_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER.fields_by_name['max_requests_per_connection']._options = None
  _CLUSTER.fields_by_name['max_requests_per_connection']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['upstream_http_protocol_options']._options = None
  _CLUSTER.fields_by_name['upstream_http_protocol_options']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['common_http_protocol_options']._options = None
  _CLUSTER.fields_by_name['common_http_protocol_options']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['http_protocol_options']._options = None
  _CLUSTER.fields_by_name['http_protocol_options']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['http2_protocol_options']._options = None
  _CLUSTER.fields_by_name['http2_protocol_options']._serialized_options = b'\030\001\212\223\267*\002\020\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['dns_refresh_rate']._options = None
  _CLUSTER.fields_by_name['dns_refresh_rate']._serialized_options = b'\372B\t\252\001\006*\004\020\300\204='
  _CLUSTER.fields_by_name['dns_lookup_family']._options = None
  _CLUSTER.fields_by_name['dns_lookup_family']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER.fields_by_name['dns_resolvers']._options = None
  _CLUSTER.fields_by_name['dns_resolvers']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['use_tcp_for_dns_lookups']._options = None
  _CLUSTER.fields_by_name['use_tcp_for_dns_lookups']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['dns_resolution_config']._options = None
  _CLUSTER.fields_by_name['dns_resolution_config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['cleanup_interval']._options = None
  _CLUSTER.fields_by_name['cleanup_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _CLUSTER.fields_by_name['protocol_selection']._options = None
  _CLUSTER.fields_by_name['protocol_selection']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER.fields_by_name['track_timeout_budgets']._options = None
  _CLUSTER.fields_by_name['track_timeout_budgets']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLUSTER._options = None
  _CLUSTER._serialized_options = b'\232\305\210\036\026\n\024envoy.api.v2.Cluster'
  _LOADBALANCINGPOLICY_POLICY._options = None
  _LOADBALANCINGPOLICY_POLICY._serialized_options = b'\232\305\210\036)\n\'envoy.api.v2.LoadBalancingPolicy.Policy'
  _LOADBALANCINGPOLICY._options = None
  _LOADBALANCINGPOLICY._serialized_options = b'\232\305\210\036\"\n envoy.api.v2.LoadBalancingPolicy'
  _UPSTREAMCONNECTIONOPTIONS._options = None
  _UPSTREAMCONNECTIONOPTIONS._serialized_options = b'\232\305\210\036(\n&envoy.api.v2.UpstreamConnectionOptions'
  _globals['_CLUSTERCOLLECTION']._serialized_start=884
  _globals['_CLUSTERCOLLECTION']._serialized_end=950
  _globals['_CLUSTER']._serialized_start=953
  _globals['_CLUSTER']._serialized_end=9655
  _globals['_CLUSTER_TRANSPORTSOCKETMATCH']._serialized_start=4604
  _globals['_CLUSTER_TRANSPORTSOCKETMATCH']._serialized_end=4804
  _globals['_CLUSTER_CUSTOMCLUSTERTYPE']._serialized_start=4807
  _globals['_CLUSTER_CUSTOMCLUSTERTYPE']._serialized_end=4940
  _globals['_CLUSTER_EDSCLUSTERCONFIG']._serialized_start=4943
  _globals['_CLUSTER_EDSCLUSTERCONFIG']._serialized_end=5085
  _globals['_CLUSTER_LBSUBSETCONFIG']._serialized_start=5088
  _globals['_CLUSTER_LBSUBSETCONFIG']._serialized_end=6201
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR']._serialized_start=5586
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR']._serialized_end=5997
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY']._serialized_start=5815
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY']._serialized_end=5936
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY']._serialized_start=5999
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY']._serialized_end=6078
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETMETADATAFALLBACKPOLICY']._serialized_start=6080
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETMETADATAFALLBACKPOLICY']._serialized_end=6157
  _globals['_CLUSTER_SLOWSTARTCONFIG']._serialized_start=6204
  _globals['_CLUSTER_SLOWSTARTCONFIG']._serialized_end=6384
  _globals['_CLUSTER_ROUNDROBINLBCONFIG']._serialized_start=6386
  _globals['_CLUSTER_ROUNDROBINLBCONFIG']._serialized_end=6483
  _globals['_CLUSTER_LEASTREQUESTLBCONFIG']._serialized_start=6486
  _globals['_CLUSTER_LEASTREQUESTLBCONFIG']._serialized_end=6762
  _globals['_CLUSTER_RINGHASHLBCONFIG']._serialized_start=6765
  _globals['_CLUSTER_RINGHASHLBCONFIG']._serialized_end=7118
  _globals['_CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION']._serialized_start=7020
  _globals['_CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION']._serialized_end=7066
  _globals['_CLUSTER_MAGLEVLBCONFIG']._serialized_start=7120
  _globals['_CLUSTER_MAGLEVLBCONFIG']._serialized_end=7198
  _globals['_CLUSTER_ORIGINALDSTLBCONFIG']._serialized_start=7201
  _globals['_CLUSTER_ORIGINALDSTLBCONFIG']._serialized_end=7395
  _globals['_CLUSTER_COMMONLBCONFIG']._serialized_start=7398
  _globals['_CLUSTER_COMMONLBCONFIG']._serialized_end=8600
  _globals['_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG']._serialized_start=8011
  _globals['_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG']._serialized_end=8228
  _globals['_CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG']._serialized_start=8230
  _globals['_CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG']._serialized_end=8325
  _globals['_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG']._serialized_start=8328
  _globals['_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG']._serialized_end=8527
  _globals['_CLUSTER_REFRESHRATE']._serialized_start=8603
  _globals['_CLUSTER_REFRESHRATE']._serialized_end=8786
  _globals['_CLUSTER_PRECONNECTPOLICY']._serialized_start=8789
  _globals['_CLUSTER_PRECONNECTPOLICY']._serialized_end=8993
  _globals['_CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY']._serialized_start=8995
  _globals['_CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY']._serialized_end=9085
  _globals['_CLUSTER_DISCOVERYTYPE']._serialized_start=9087
  _globals['_CLUSTER_DISCOVERYTYPE']._serialized_end=9174
  _globals['_CLUSTER_LBPOLICY']._serialized_start=9177
  _globals['_CLUSTER_LBPOLICY']._serialized_end=9341
  _globals['_CLUSTER_DNSLOOKUPFAMILY']._serialized_start=9343
  _globals['_CLUSTER_DNSLOOKUPFAMILY']._serialized_end=9423
  _globals['_CLUSTER_CLUSTERPROTOCOLSELECTION']._serialized_start=9425
  _globals['_CLUSTER_CLUSTERPROTOCOLSELECTION']._serialized_end=9509
  _globals['_LOADBALANCINGPOLICY']._serialized_start=9658
  _globals['_LOADBALANCINGPOLICY']._serialized_end=9972
  _globals['_LOADBALANCINGPOLICY_POLICY']._serialized_start=9753
  _globals['_LOADBALANCINGPOLICY_POLICY']._serialized_end=9931
  _globals['_UPSTREAMCONNECTIONOPTIONS']._serialized_start=9975
  _globals['_UPSTREAMCONNECTIONOPTIONS']._serialized_end=10166
  _globals['_TRACKCLUSTERSTATS']._serialized_start=10168
  _globals['_TRACKCLUSTERSTATS']._serialized_end=10244
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import auth_pb2 as google_dot_api_dot_auth__pb2
from google.api import backend_pb2 as google_dot_api_dot_backend__pb2
from google.api import billing_pb2 as google_dot_api_dot_billing__pb2
from google.api import context_pb2 as google_dot_api_dot_context__pb2
from google.api import control_pb2 as google_dot_api_dot_control__pb2
from google.api import documentation_pb2 as google_dot_api_dot_documentation__pb2
from google.api import endpoint_pb2 as google_dot_api_dot_endpoint__pb2
from google.api import http_pb2 as google_dot_api_dot_http__pb2
from google.api import label_pb2 as google_dot_api_dot_label__pb2
from google.api import log_pb2 as google_dot_api_dot_log__pb2
from google.api import logging_pb2 as google_dot_api_dot_logging__pb2
from google.api import metric_pb2 as google_dot_api_dot_metric__pb2
from google.api import monitored_resource_pb2 as google_dot_api_dot_monitored__resource__pb2
from google.api import monitoring_pb2 as google_dot_api_dot_monitoring__pb2
from google.api import quota_pb2 as google_dot_api_dot_quota__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import source_info_pb2 as google_dot_api_dot_source__info__pb2
from google.api import system_parameter_pb2 as google_dot_api_dot_system__parameter__pb2
from google.api import usage_pb2 as google_dot_api_dot_usage__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import api_pb2 as google_dot_protobuf_dot_api__pb2
from google.protobuf import type_pb2 as google_dot_protobuf_dot_type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18google/api/service.proto\x12\ngoogle.api\x1a\x15google/api/auth.proto\x1a\x18google/api/backend.proto\x1a\x18google/api/billing.proto\x1a\x18google/api/context.proto\x1a\x18google/api/control.proto\x1a\x1egoogle/api/documentation.proto\x1a\x19google/api/endpoint.proto\x1a\x15google/api/http.proto\x1a\x16google/api/label.proto\x1a\x14google/api/log.proto\x1a\x18google/api/logging.proto\x1a\x17google/api/metric.proto\x1a#google/api/monitored_resource.proto\x1a\x1bgoogle/api/monitoring.proto\x1a\x16google/api/quota.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/api/source_info.proto\x1a!google/api/system_parameter.proto\x1a\x16google/api/usage.proto\x1a\x19google/protobuf/any.proto\x1a\x19google/protobuf/api.proto\x1a\x1agoogle/protobuf/type.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xda\x07\n\x07Service\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x1b\n\x13producer_project_id\x18\x16 \x01(\t\x12\n\n\x02id\x18! \x01(\t\x12\"\n\x04\x61pis\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Api\x12$\n\x05types\x18\x04 \x03(\x0b\x32\x15.google.protobuf.Type\x12$\n\x05\x65nums\x18\x05 \x03(\x0b\x32\x15.google.protobuf.Enum\x12\x30\n\rdocumentation\x18\x06 \x01(\x0b\x32\x19.google.api.Documentation\x12$\n\x07\x62\x61\x63kend\x18\x08 \x01(\x0b\x32\x13.google.api.Backend\x12\x1e\n\x04http\x18\t \x01(\x0b\x32\x10.google.api.Http\x12 \n\x05quota\x18\n \x01(\x0b\x32\x11.google.api.Quota\x12\x32\n\x0e\x61uthentication\x18\x0b \x01(\x0b\x32\x1a.google.api.Authentication\x12$\n\x07\x63ontext\x18\x0c \x01(\x0b\x32\x13.google.api.Context\x12 \n\x05usage\x18\x0f \x01(\x0b\x32\x11.google.api.Usage\x12\'\n\tendpoints\x18\x12 \x03(\x0b\x32\x14.google.api.Endpoint\x12$\n\x07\x63ontrol\x18\x15 \x01(\x0b\x32\x13.google.api.Control\x12\'\n\x04logs\x18\x17 \x03(\x0b\x32\x19.google.api.LogDescriptor\x12-\n\x07metrics\x18\x18 \x03(\x0b\x32\x1c.google.api.MetricDescriptor\x12\x44\n\x13monitored_resources\x18\x19 \x03(\x0b\x32\'.google.api.MonitoredResourceDescriptor\x12$\n\x07\x62illing\x18\x1a \x01(\x0b\x32\x13.google.api.Billing\x12$\n\x07logging\x18\x1b \x01(\x0b\x32\x13.google.api.Logging\x12*\n\nmonitoring\x18\x1c \x01(\x0b\x32\x16.google.api.Monitoring\x12\x37\n\x11system_parameters\x18\x1d \x01(\x0b\x32\x1c.google.api.SystemParameters\x12+\n\x0bsource_info\x18% \x01(\x0b\x32\x16.google.api.SourceInfo\x12\x38\n\x0e\x63onfig_version\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x02\x18\x01\x42n\n\x0e\x63om.google.apiB\x0cServiceProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\014ServiceProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _SERVICE.fields_by_name['config_version']._options = None
  _SERVICE.fields_by_name['config_version']._serialized_options = b'\030\001'
  _globals['_SERVICE']._serialized_start=667
  _globals['_SERVICE']._serialized_end=1653
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/cache/v3/cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/filters/http/cache/v3/cache.proto\x12&envoy.extensions.filters.http.cache.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x91\x05\n\x0b\x43\x61\x63heConfig\x12*\n\x0ctyped_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12,\n\x08\x64isabled\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x14\x61llowed_vary_headers\x18\x02 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12`\n\x12key_creator_params\x18\x03 \x01(\x0b\x32\x44.envoy.extensions.filters.http.cache.v3.CacheConfig.KeyCreatorParams\x12\x16\n\x0emax_body_bytes\x18\x04 \x01(\r\x1a\xae\x02\n\x10KeyCreatorParams\x12\x16\n\x0e\x65xclude_scheme\x18\x01 \x01(\x08\x12\x14\n\x0c\x65xclude_host\x18\x02 \x01(\x08\x12O\n\x19query_parameters_included\x18\x03 \x03(\x0b\x32,.envoy.config.route.v3.QueryParameterMatcher\x12O\n\x19query_parameters_excluded\x18\x04 \x03(\x0b\x32,.envoy.config.route.v3.QueryParameterMatcher:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams:9\x9a\xc5\x88\x1e\x34\n2envoy.config.filter.http.cache.v2alpha.CacheConfigB\xa3\x01\n4io.envoyproxy.envoy.extensions.filters.http.cache.v3B\nCacheProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/cache/v3;cachev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.cache.v3.cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.filters.http.cache.v3B\nCacheProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/cache/v3;cachev3\272\200\310\321\006\002\020\002'
  _CACHECONFIG_KEYCREATORPARAMS._options = None
  _CACHECONFIG_KEYCREATORPARAMS._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams'
  _CACHECONFIG._options = None
  _CACHECONFIG._serialized_options = b'\232\305\210\0364\n2envoy.config.filter.http.cache.v2alpha.CacheConfig'
  _globals['_CACHECONFIG']._serialized_start=302
  _globals['_CACHECONFIG']._serialized_end=959
  _globals['_CACHECONFIG_KEYCREATORPARAMS']._serialized_start=598
  _globals['_CACHECONFIG_KEYCREATORPARAMS']._serialized_end=900
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/rpc/context/attribute_context.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*google/rpc/context/attribute_context.proto\x12\x12google.rpc.context\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x83\x10\n\x10\x41ttributeContext\x12\x39\n\x06origin\x18\x07 \x01(\x0b\x32).google.rpc.context.AttributeContext.Peer\x12\x39\n\x06source\x18\x01 \x01(\x0b\x32).google.rpc.context.AttributeContext.Peer\x12>\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32).google.rpc.context.AttributeContext.Peer\x12=\n\x07request\x18\x03 \x01(\x0b\x32,.google.rpc.context.AttributeContext.Request\x12?\n\x08response\x18\x04 \x01(\x0b\x32-.google.rpc.context.AttributeContext.Response\x12?\n\x08resource\x18\x05 \x01(\x0b\x32-.google.rpc.context.AttributeContext.Resource\x12\x35\n\x03\x61pi\x18\x06 \x01(\x0b\x32(.google.rpc.context.AttributeContext.Api\x12(\n\nextensions\x18\x08 \x03(\x0b\x32\x14.google.protobuf.Any\x1a\xbe\x01\n\x04Peer\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12\x45\n\x06labels\x18\x06 \x03(\x0b\x32\x35.google.rpc.context.AttributeContext.Peer.LabelsEntry\x12\x11\n\tprincipal\x18\x07 \x01(\t\x12\x13\n\x0bregion_code\x18\x08 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aL\n\x03\x41pi\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x1a\x7f\n\x04\x41uth\x12\x11\n\tprincipal\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t\x12\x11\n\tpresenter\x18\x03 \x01(\t\x12\'\n\x06\x63laims\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\raccess_levels\x18\x05 \x03(\t\x1a\xef\x02\n\x07Request\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12J\n\x07headers\x18\x03 \x03(\x0b\x32\x39.google.rpc.context.AttributeContext.Request.HeadersEntry\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\x0e\n\x06scheme\x18\x06 \x01(\t\x12\r\n\x05query\x18\x07 \x01(\t\x12(\n\x04time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04size\x18\n \x01(\x03\x12\x10\n\x08protocol\x18\x0b \x01(\t\x12\x0e\n\x06reason\x18\x0c \x01(\t\x12\x37\n\x04\x61uth\x18\r \x01(\x0b\x32).google.rpc.context.AttributeContext.Auth\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x81\x02\n\x08Response\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12K\n\x07headers\x18\x03 \x03(\x0b\x32:.google.rpc.context.AttributeContext.Response.HeadersEntry\x12(\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0f\x62\x61\x63kend_latency\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x90\x04\n\x08Resource\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12I\n\x06labels\x18\x04 \x03(\x0b\x32\x39.google.rpc.context.AttributeContext.Resource.LabelsEntry\x12\x0b\n\x03uid\x18\x05 \x01(\t\x12S\n\x0b\x61nnotations\x18\x06 \x03(\x0b\x32>.google.rpc.context.AttributeContext.Resource.AnnotationsEntry\x12\x14\n\x0c\x64isplay_name\x18\x07 \x01(\t\x12/\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x64\x65lete_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x65tag\x18\x0b \x01(\t\x12\x10\n\x08location\x18\x0c \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x8b\x01\n\x16\x63om.google.rpc.contextB\x15\x41ttributeContextProtoP\x01ZUgoogle.golang.org/genproto/googleapis/rpc/context/attribute_context;attribute_context\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.rpc.context.attribute_context_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.google.rpc.contextB\025AttributeContextProtoP\001ZUgoogle.golang.org/genproto/googleapis/rpc/context/attribute_context;attribute_context\370\001\001'
  _ATTRIBUTECONTEXT_PEER_LABELSENTRY._options = None
  _ATTRIBUTECONTEXT_PEER_LABELSENTRY._serialized_options = b'8\001'
  _ATTRIBUTECONTEXT_REQUEST_HEADERSENTRY._options = None
  _ATTRIBUTECONTEXT_REQUEST_HEADERSENTRY._serialized_options = b'8\001'
  _ATTRIBUTECONTEXT_RESPONSE_HEADERSENTRY._options = None
  _ATTRIBUTECONTEXT_RESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _ATTRIBUTECONTEXT_RESOURCE_LABELSENTRY._options = None
  _ATTRIBUTECONTEXT_RESOURCE_LABELSENTRY._serialized_options = b'8\001'
  _ATTRIBUTECONTEXT_RESOURCE_ANNOTATIONSENTRY._options = None
  _ATTRIBUTECONTEXT_RESOURCE_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT']._serialized_start=189
  _globals['_ATTRIBUTECONTEXT']._serialized_end=2240
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_start=682
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_end=872
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_start=827
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_end=872
  _globals['_ATTRIBUTECONTEXT_API']._serialized_start=874
  _globals['_ATTRIBUTECONTEXT_API']._serialized_end=950
  _globals['_ATTRIBUTECONTEXT_AUTH']._serialized_start=952
  _globals['_ATTRIBUTECONTEXT_AUTH']._serialized_end=1079
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_start=1082
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_end=1449
  _globals['_ATTRIBUTECONTEXT_REQUEST_HEADERSENTRY']._serialized_start=1403
  _globals['_ATTRIBUTECONTEXT_REQUEST_HEADERSENTRY']._serialized_end=1449
  _globals['_ATTRIBUTECONTEXT_RESPONSE']._serialized_start=1452
  _globals['_ATTRIBUTECONTEXT_RESPONSE']._serialized_end=1709
  _globals['_ATTRIBUTECONTEXT_RESPONSE_HEADERSENTRY']._serialized_start=1403
  _globals['_ATTRIBUTECONTEXT_RESPONSE_HEADERSENTRY']._serialized_end=1449
  _globals['_ATTRIBUTECONTEXT_RESOURCE']._serialized_start=1712
  _globals['_ATTRIBUTECONTEXT_RESOURCE']._serialized_end=2240
  _globals['_ATTRIBUTECONTEXT_RESOURCE_LABELSENTRY']._serialized_start=827
  _globals['_ATTRIBUTECONTEXT_RESOURCE_LABELSENTRY']._serialized_end=872
  _globals['_ATTRIBUTECONTEXT_RESOURCE_ANNOTATIONSENTRY']._serialized_start=2190
  _globals['_ATTRIBUTECONTEXT_RESOURCE_ANNOTATIONSENTRY']._serialized_end=2240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/watchdog/profile_action/v3/profile_action.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/watchdog/profile_action/v3/profile_action.proto\x12+envoy.extensions.watchdog.profile_action.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x7f\n\x13ProfileActionConfig\x12\x33\n\x10profile_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1d\n\x0cprofile_path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x0cmax_profiles\x18\x03 \x01(\x04\x42\xbe\x01\n9io.envoyproxy.envoy.extensions.watchdog.profile_action.v3B\x12ProfileActionProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/watchdog/profile_action/v3;profile_actionv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.watchdog.profile_action.v3.profile_action_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9io.envoyproxy.envoy.extensions.watchdog.profile_action.v3B\022ProfileActionProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/watchdog/profile_action/v3;profile_actionv3\272\200\310\321\006\002\020\002'
  _PROFILEACTIONCONFIG.fields_by_name['profile_path']._options = None
  _PROFILEACTIONCONFIG.fields_by_name['profile_path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_PROFILEACTIONCONFIG']._serialized_start=201
  _globals['_PROFILEACTIONCONFIG']._serialized_end=328
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/quic/v3/quic_transport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.tls.v3 import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/transport_sockets/quic/v3/quic_transport.proto\x12*envoy.extensions.transport_sockets.quic.v3\x1a\x33\x65nvoy/extensions/transport_sockets/tls/v3/tls.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbb\x01\n\x17QuicDownstreamTransport\x12i\n\x16\x64ownstream_tls_context\x18\x01 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x35\n\x11\x65nable_early_data\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"~\n\x15QuicUpstreamTransport\x12\x65\n\x14upstream_tls_context\x18\x01 \x01(\x0b\x32=.envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\xb2\x01\n8io.envoyproxy.envoy.extensions.transport_sockets.quic.v3B\x12QuicTransportProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/quic/v3;quicv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.quic.v3.quic_transport_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.transport_sockets.quic.v3B\022QuicTransportProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/quic/v3;quicv3\272\200\310\321\006\002\020\002'
  _QUICDOWNSTREAMTRANSPORT.fields_by_name['downstream_tls_context']._options = None
  _QUICDOWNSTREAMTRANSPORT.fields_by_name['downstream_tls_context']._serialized_options = b'\372B\005\212\001\002\020\001'
  _QUICUPSTREAMTRANSPORT.fields_by_name['upstream_tls_context']._options = None
  _QUICUPSTREAMTRANSPORT.fields_by_name['upstream_tls_context']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_QUICDOWNSTREAMTRANSPORT']._serialized_start=253
  _globals['_QUICDOWNSTREAMTRANSPORT']._serialized_end=440
  _globals['_QUICUPSTREAMTRANSPORT']._serialized_start=442
  _globals['_QUICUPSTREAMTRANSPORT']._serialized_end=568
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto\x12\x35\x65nvoy.extensions.filters.http.grpc_json_transcoder.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xde\x0b\n\x12GrpcJsonTranscoder\x12\x1a\n\x10proto_descriptor\x18\x01 \x01(\tH\x00\x12\x1e\n\x14proto_descriptor_bin\x18\x04 \x01(\x0cH\x00\x12\x10\n\x08services\x18\x02 \x03(\t\x12m\n\rprint_options\x18\x03 \x01(\x0b\x32V.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions\x12$\n\x1cmatch_incoming_request_route\x18\x05 \x01(\x08\x12 \n\x18ignored_query_parameters\x18\x06 \x03(\t\x12\x14\n\x0c\x61uto_mapping\x18\x07 \x01(\x08\x12\'\n\x1fignore_unknown_query_parameters\x18\x08 \x01(\x08\x12\x1b\n\x13\x63onvert_grpc_status\x18\t \x01(\x08\x12~\n\x11url_unescape_spec\x18\n \x01(\x0e\x32Y.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.UrlUnescapeSpecB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12!\n\x19query_param_unescape_plus\x18\x0c \x01(\x08\x12&\n\x1ematch_unregistered_custom_verb\x18\r \x01(\x08\x12\x86\x01\n\x1arequest_validation_options\x18\x0b \x01(\x0b\x32\x62.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.RequestValidationOptions\x12%\n\x1d\x63\x61se_insensitive_enum_parsing\x18\x0e \x01(\x08\x12\x44\n\x15max_request_body_size\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x45\n\x16max_response_body_size\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x1a\x86\x02\n\x0cPrintOptions\x12\x16\n\x0e\x61\x64\x64_whitespace\x18\x01 \x01(\x08\x12%\n\x1d\x61lways_print_primitive_fields\x18\x02 \x01(\x08\x12\"\n\x1a\x61lways_print_enums_as_ints\x18\x03 \x01(\x08\x12\"\n\x1apreserve_proto_field_names\x18\x04 \x01(\x08\x12 \n\x18stream_newline_delimited\x18\x05 \x01(\x08:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions\x1a\x90\x01\n\x18RequestValidationOptions\x12\x1d\n\x15reject_unknown_method\x18\x01 \x01(\x08\x12\'\n\x1freject_unknown_query_parameters\x18\x02 \x01(\x08\x12,\n$reject_binding_body_field_collisions\x18\x03 \x01(\x08\"j\n\x0fUrlUnescapeSpec\x12\"\n\x1e\x41LL_CHARACTERS_EXCEPT_RESERVED\x10\x00\x12\x1f\n\x1b\x41LL_CHARACTERS_EXCEPT_SLASH\x10\x01\x12\x12\n\x0e\x41LL_CHARACTERS\x10\x02:@\x9a\xc5\x88\x1e;\n9envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoderB\x15\n\x0e\x64\x65scriptor_set\x12\x03\xf8\x42\x01\x42\xd5\x01\nCio.envoyproxy.envoy.extensions.filters.http.grpc_json_transcoder.v3B\x0fTranscoderProtoP\x01Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_json_transcoder/v3;grpc_json_transcoderv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_json_transcoder.v3.transcoder_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCio.envoyproxy.envoy.extensions.filters.http.grpc_json_transcoder.v3B\017TranscoderProtoP\001Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_json_transcoder/v3;grpc_json_transcoderv3\272\200\310\321\006\002\020\002'
  _GRPCJSONTRANSCODER_PRINTOPTIONS._options = None
  _GRPCJSONTRANSCODER_PRINTOPTIONS._serialized_options = b'\232\305\210\036H\nFenvoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions'
  _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']._options = None
  _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']._serialized_options = b'\370B\001'
  _GRPCJSONTRANSCODER.fields_by_name['url_unescape_spec']._options = None
  _GRPCJSONTRANSCODER.fields_by_name['url_unescape_spec']._serialized_options = b'\372B\005\202\001\002\020\001'
  _GRPCJSONTRANSCODER.fields_by_name['max_request_body_size']._options = None
  _GRPCJSONTRANSCODER.fields_by_name['max_request_body_size']._serialized_options = b'\372B\004*\002 \000'
  _GRPCJSONTRANSCODER.fields_by_name['max_response_body_size']._options = None
  _GRPCJSONTRANSCODER.fields_by_name['max_response_body_size']._serialized_options = b'\372B\004*\002 \000'
  _GRPCJSONTRANSCODER._options = None
  _GRPCJSONTRANSCODER._serialized_options = b'\232\305\210\036;\n9envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder'
  _globals['_GRPCJSONTRANSCODER']._serialized_start=253
  _globals['_GRPCJSONTRANSCODER']._serialized_end=1755
  _globals['_GRPCJSONTRANSCODER_PRINTOPTIONS']._serialized_start=1149
  _globals['_GRPCJSONTRANSCODER_PRINTOPTIONS']._serialized_end=1411
  _globals['_GRPCJSONTRANSCODER_REQUESTVALIDATIONOPTIONS']._serialized_start=1414
  _globals['_GRPCJSONTRANSCODER_REQUESTVALIDATIONOPTIONS']._serialized_end=1558
  _globals['_GRPCJSONTRANSCODER_URLUNESCAPESPEC']._serialized_start=1560
  _globals['_GRPCJSONTRANSCODER_URLUNESCAPESPEC']._serialized_end=1666
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/cluster/circuit_breaker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*envoy/api/v2/cluster/circuit_breaker.proto\x12\x14\x65nvoy.api.v2.cluster\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa2\x05\n\x0f\x43ircuitBreakers\x12\x44\n\nthresholds\x18\x01 \x03(\x0b\x32\x30.envoy.api.v2.cluster.CircuitBreakers.Thresholds\x1a\xc8\x04\n\nThresholds\x12>\n\x08priority\x18\x01 \x01(\x0e\x32\".envoy.api.v2.core.RoutingPriorityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x35\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12:\n\x14max_pending_requests\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0cmax_requests\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bmax_retries\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12R\n\x0cretry_budget\x18\x08 \x01(\x0b\x32<.envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget\x12\x17\n\x0ftrack_remaining\x18\x06 \x01(\x08\x12:\n\x14max_connection_pools\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aw\n\x0bRetryBudget\x12+\n\x0e\x62udget_percent\x18\x01 \x01(\x0b\x32\x13.envoy.type.Percent\x12;\n\x15min_retry_concurrency\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xd4\x01\n\"io.envoyproxy.envoy.api.v2.clusterB\x13\x43ircuitBreakerProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\xaa\x02\x16\x45nvoy.Api.V2.ClusterNS\xea\x02\x19\x45nvoy::Api::V2::ClusterNS\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.config.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.cluster.circuit_breaker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.api.v2.clusterB\023CircuitBreakerProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\252\002\026Envoy.Api.V2.ClusterNS\352\002\031Envoy::Api::V2::ClusterNS\362\230\376\217\005\031\022\027envoy.config.cluster.v3\272\200\310\321\006\002\020\001'
  _CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority']._options = None
  _CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_CIRCUITBREAKERS']._serialized_start=245
  _globals['_CIRCUITBREAKERS']._serialized_end=919
  _globals['_CIRCUITBREAKERS_THRESHOLDS']._serialized_start=335
  _globals['_CIRCUITBREAKERS_THRESHOLDS']._serialized_end=919
  _globals['_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET']._serialized_start=800
  _globals['_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET']._serialized_end=919
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/collector/metrics/v1/metrics_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opentelemetry.proto.metrics.v1 import metrics_pb2 as opentelemetry_dot_proto_dot_metrics_dot_v1_dot_metrics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>opentelemetry/proto/collector/metrics/v1/metrics_service.proto\x12(opentelemetry.proto.collector.metrics.v1\x1a,opentelemetry/proto/metrics/v1/metrics.proto\"h\n\x1b\x45xportMetricsServiceRequest\x12I\n\x10resource_metrics\x18\x01 \x03(\x0b\x32/.opentelemetry.proto.metrics.v1.ResourceMetrics\"\x1e\n\x1c\x45xportMetricsServiceResponse2\xac\x01\n\x0eMetricsService\x12\x99\x01\n\x06\x45xport\x12\x45.opentelemetry.proto.collector.metrics.v1.ExportMetricsServiceRequest\x1a\x46.opentelemetry.proto.collector.metrics.v1.ExportMetricsServiceResponse\"\x00\x42\x8f\x01\n+io.opentelemetry.proto.collector.metrics.v1B\x13MetricsServiceProtoP\x01ZIgithub.com/open-telemetry/opentelemetry-proto/gen/go/collector/metrics/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opentelemetry.proto.collector.metrics.v1.metrics_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+io.opentelemetry.proto.collector.metrics.v1B\023MetricsServiceProtoP\001ZIgithub.com/open-telemetry/opentelemetry-proto/gen/go/collector/metrics/v1'
  _globals['_EXPORTMETRICSSERVICEREQUEST']._serialized_start=154
  _globals['_EXPORTMETRICSSERVICEREQUEST']._serialized_end=258
  _globals['_EXPORTMETRICSSERVICERESPONSE']._serialized_start=260
  _globals['_EXPORTMETRICSSERVICERESPONSE']._serialized_end=290
  _globals['_METRICSSERVICE']._serialized_start=293
  _globals['_METRICSSERVICE']._serialized_end=465
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/thrift_proxy/v2alpha1/thrift_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.filter.network.thrift_proxy.v2alpha1 import route_pb2 as envoy_dot_config_dot_filter_dot_network_dot_thrift__proxy_dot_v2alpha1_dot_route__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/config/filter/network/thrift_proxy/v2alpha1/thrift_proxy.proto\x12\x31\x65nvoy.config.filter.network.thrift_proxy.v2alpha1\x1a=envoy/config/filter/network/thrift_proxy/v2alpha1/route.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9d\x03\n\x0bThriftProxy\x12]\n\ttransport\x18\x02 \x01(\x0e\x32@.envoy.config.filter.network.thrift_proxy.v2alpha1.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12[\n\x08protocol\x18\x03 \x01(\x0e\x32?.envoy.config.filter.network.thrift_proxy.v2alpha1.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12[\n\x0croute_config\x18\x04 \x01(\x0b\x32\x45.envoy.config.filter.network.thrift_proxy.v2alpha1.RouteConfiguration\x12W\n\x0ethrift_filters\x18\x05 \x03(\x0b\x32?.envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilter\"\x91\x01\n\x0cThriftFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"\xd3\x01\n\x15ThriftProtocolOptions\x12]\n\ttransport\x18\x01 \x01(\x0e\x32@.envoy.config.filter.network.thrift_proxy.v2alpha1.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12[\n\x08protocol\x18\x02 \x01(\x0e\x32?.envoy.config.filter.network.thrift_proxy.v2alpha1.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01*I\n\rTransportType\x12\x12\n\x0e\x41UTO_TRANSPORT\x10\x00\x12\n\n\x06\x46RAMED\x10\x01\x12\x0c\n\x08UNFRAMED\x10\x02\x12\n\n\x06HEADER\x10\x03*W\n\x0cProtocolType\x12\x11\n\rAUTO_PROTOCOL\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x0e\n\nLAX_BINARY\x10\x02\x12\x0b\n\x07\x43OMPACT\x10\x03\x12\x0b\n\x07TWITTER\x10\x04\x42\xef\x01\n?io.envoyproxy.envoy.config.filter.network.thrift_proxy.v2alpha1B\x10ThriftProxyProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/thrift_proxy/v2alpha1\xf2\x98\xfe\x8f\x05\x32\x12\x30\x65nvoy.extensions.filters.network.thrift_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.thrift_proxy.v2alpha1.thrift_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.config.filter.network.thrift_proxy.v2alpha1B\020ThriftProxyProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/thrift_proxy/v2alpha1\362\230\376\217\0052\0220envoy.extensions.filters.network.thrift_proxy.v3\272\200\310\321\006\002\020\001'
  _THRIFTPROXY.fields_by_name['transport']._options = None
  _THRIFTPROXY.fields_by_name['transport']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROXY.fields_by_name['protocol']._options = None
  _THRIFTPROXY.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROXY.fields_by_name['stat_prefix']._options = None
  _THRIFTPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _THRIFTFILTER.fields_by_name['name']._options = None
  _THRIFTFILTER.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _THRIFTFILTER.fields_by_name['config']._options = None
  _THRIFTFILTER.fields_by_name['config']._serialized_options = b'\030\001'
  _THRIFTPROTOCOLOPTIONS.fields_by_name['transport']._options = None
  _THRIFTPROTOCOLOPTIONS.fields_by_name['transport']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROTOCOLOPTIONS.fields_by_name['protocol']._options = None
  _THRIFTPROTOCOLOPTIONS.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_TRANSPORTTYPE']._serialized_start=1109
  _globals['_TRANSPORTTYPE']._serialized_end=1182
  _globals['_PROTOCOLTYPE']._serialized_start=1184
  _globals['_PROTOCOLTYPE']._serialized_end=1271
  _globals['_THRIFTPROXY']._serialized_start=332
  _globals['_THRIFTPROXY']._serialized_end=745
  _globals['_THRIFTFILTER']._serialized_start=748
  _globals['_THRIFTFILTER']._serialized_end=893
  _globals['_THRIFTPROTOCOLOPTIONS']._serialized_start=896
  _globals['_THRIFTPROTOCOLOPTIONS']._serialized_end=1107
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/local_rate_limit/v2alpha/local_rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type import token_bucket_pb2 as envoy_dot_type_dot_token__bucket__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKenvoy/config/filter/network/local_rate_limit/v2alpha/local_rate_limit.proto\x12\x34\x65nvoy.config.filter.network.local_rate_limit.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1d\x65nvoy/type/token_bucket.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa7\x01\n\x0eLocalRateLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x37\n\x0ctoken_bucket\x18\x02 \x01(\x0b\x32\x17.envoy.type.TokenBucketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12>\n\x0fruntime_enabled\x18\x03 \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlagB\xfb\x01\nBio.envoyproxy.envoy.config.filter.network.local_rate_limit.v2alphaB\x13LocalRateLimitProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/network/local_rate_limit/v2alpha\xf2\x98\xfe\x8f\x05\x35\x12\x33\x65nvoy.extensions.filters.network.local_ratelimit.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.local_rate_limit.v2alpha.local_rate_limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.config.filter.network.local_rate_limit.v2alphaB\023LocalRateLimitProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/network/local_rate_limit/v2alpha\362\230\376\217\0055\0223envoy.extensions.filters.network.local_ratelimit.v3\272\200\310\321\006\002\020\001'
  _LOCALRATELIMIT.fields_by_name['stat_prefix']._options = None
  _LOCALRATELIMIT.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _LOCALRATELIMIT.fields_by_name['token_bucket']._options = None
  _LOCALRATELIMIT.fields_by_name['token_bucket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_LOCALRATELIMIT']._serialized_start=283
  _globals['_LOCALRATELIMIT']._serialized_end=450
# @@protoc_insertion_point(module_scope)
